Package: Rmmquant
Type: Package
Title: RNA-Seq multi-mapping Reads Quantification Tool
Version: 1.28.0
Date: 2023-04-05
Authors@R: person("Zytnicki", "Matthias", email = "matthias.zytnicki@inra.fr",
  role = c("aut", "cre"))
Description: RNA-Seq is currently used routinely, and it provides accurate
  information on gene transcription. However, the method cannot accurately
  estimate duplicated genes expression. Several strategies have been previously
  used, but all of them provide biased results.
  With Rmmquant, if a read maps at different positions, the tool detects that
  the corresponding genes are duplicated; it merges the genes and creates a
  merged gene. The counts of ambiguous reads is then based on the input genes
  and the merged genes.
  Rmmquant is a drop-in replacement of the widely used tools findOverlaps and
  featureCounts that handles multi-mapping reads in an unabiased way.
License: GPL-3
Encoding: UTF-8
SystemRequirements: C++11
Depends: R (>= 3.6)
Imports: Rcpp (>= 0.12.8), methods, S4Vectors, GenomicRanges,
        SummarizedExperiment, devtools, TBX20BamSubset,
        TxDb.Mmusculus.UCSC.mm9.knownGene, org.Mm.eg.db, DESeq2,
        apeglm, BiocStyle
LinkingTo: Rcpp
RoxygenNote: 7.0.2
biocViews: GeneExpression, Transcription
Suggests: knitr, rmarkdown, testthat
VignetteBuilder: knitr
git_url: https://git.bioconductor.org/packages/Rmmquant
git_branch: RELEASE_3_22
git_last_commit: 60d48d5
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
NeedsCompilation: yes
Packaged: 2025-10-30 06:06:52 UTC; biocbuild
Author: Zytnicki Matthias [aut, cre]
Maintainer: Zytnicki Matthias <matthias.zytnicki@inra.fr>
