# Generated by roxygen2: do not edit by hand

export(RmmquantClassExample)
export(RmmquantExample)
export(RmmquantRun)
export(counts)
exportMethods(counts)
exportMethods(show)
import(BiocStyle)
import(GenomicRanges)
import(S4Vectors)
import(SummarizedExperiment)
import(TBX20BamSubset)
import(TxDb.Mmusculus.UCSC.mm9.knownGene)
import(devtools)
import(org.Mm.eg.db)
importFrom(DESeq2,DESeq)
importFrom(DESeq2,DESeqDataSetFromMatrix)
importFrom(DESeq2,lfcShrink)
importFrom(Rcpp,evalCpp)
importFrom(methods,is)
importFrom(methods,new)
useDynLib(Rmmquant)
