# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

rcpp_parseGenomicRanges <- function(genomicRanges) {
    invisible(.Call('_Rmmquant_rcpp_parseGenomicRanges', PACKAGE = 'Rmmquant', genomicRanges))
}

rcpp_Rmmquant <- function(annotationFile, readsFiles, genomicRanges, genomicRangesList, sampleNames, overlap, strands, sorts, countThreshold, mergeThreshold, printGeneName, quiet, progress, nThreads, formats, nOverlapDiff, pcOverlapDiff) {
    .Call('_Rmmquant_rcpp_Rmmquant', PACKAGE = 'Rmmquant', annotationFile, readsFiles, genomicRanges, genomicRangesList, sampleNames, overlap, strands, sorts, countThreshold, mergeThreshold, printGeneName, quiet, progress, nThreads, formats, nOverlapDiff, pcOverlapDiff)
}

