% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/AllClass.R
\name{show,RmmquantClass-method}
\alias{show,RmmquantClass-method}
\title{Show the content of an \code{RmmquantClass} object.}
\usage{
\S4method{show}{RmmquantClass}(object)
}
\arguments{
\item{object}{An \code{RmmquantClass} object.}
}
\value{
A description of the object.
}
\description{
Show the content of an \code{RmmquantClass} object.
}
\examples{
example <- RmmquantClassExample()
example

}
